@@ -22,6 +22,7 @@ import (
 	"io"
 	"io/ioutil"
 	"net/http"
+	"net/http/httptest"
 	"net/url"
 	"regexp"
 	"strings"
@@ -190,7 +191,7 @@ func TestInterceptor_ExecuteTrigger(t *testing.T) {
 			want:    []byte(`{"count":1,"measure":1.7}`),
 		},
 		{
-			name: "validating a secret",
+			name: "validating a secret with a namespace and name",
 			CEL: &triggersv1.CELInterceptor{
 				Filter: "header.canonical('X-Secret-Token').compareSecret('token', 'test-secret', 'testing-ns') && body.count == 1.0",
 			},
@@ -213,7 +214,19 @@ func TestInterceptor_ExecuteTrigger(t *testing.T) {
 				},
 			},
 			payload: ioutil.NopCloser(bytes.NewBufferString(`{"event":[{"testing":"value"},{"testing":"another"}]}`)),
-			want:    []byte(`{"event":["value", "another"]}`),
+			want:    []byte(`{"event":["value","another"]}`),
+		},
+		{
+			name: "return different types of expression",
+			CEL: &triggersv1.CELInterceptor{
+				Overlays: []triggersv1.CELOverlay{
+					{Key: "test.one", Expression: "'yo'"},
+					{Key: "test.two", Expression: "false ? true : false"},
+					{Key: "test.three", Expression: "body.test"},
+				},
+			},
+			payload: ioutil.NopCloser(bytes.NewBufferString(`{"value":"test","test":{"other":"thing"}}`)),
+			want:    []byte(`{"test":{"one":"yo","two":false,"three":{"other": "thing"},"other":"thing"},"value":"test"}`),
 		},
 	}
 	for _, tt := range tests {
@@ -226,6 +239,7 @@ func TestInterceptor_ExecuteTrigger(t *testing.T) {
 			}
 			w := NewInterceptor(tt.CEL, kubeClient, "testing-ns", logger)
 			request := &http.Request{
+				URL:  mustParseURL(t, "https://testing.example.com"),
 				Body: tt.payload,
 				Header: http.Header{
 					"Content-Type":   []string{"application/json"},
@@ -307,7 +321,7 @@ func TestInterceptor_ExecuteTrigger_Errors(t *testing.T) {
 				},
 			},
 			payload: []byte(`{"value":"test"}`),
-			want:    "failed to evaluate overlay expression 'test.value'",
+			want:    `expression "test.value" check failed: ERROR:.*undeclared reference to 'test'`,
 		},
 	}
 	for _, tt := range tests {
@@ -318,6 +332,7 @@ func TestInterceptor_ExecuteTrigger_Errors(t *testing.T) {
 				Logger: logger,
 			}
 			request := &http.Request{
+				URL:  mustParseURL(t, "https://example.com/testing"),
 				Body: ioutil.NopCloser(bytes.NewReader(tt.payload)),
 				GetBody: func() (io.ReadCloser, error) {
 					return ioutil.NopCloser(bytes.NewReader(tt.payload)), nil
@@ -349,6 +364,7 @@ func TestExpressionEvaluation(t *testing.T) {
 		},
 		"b64value":  "ZXhhbXBsZQ==",
 		"json_body": `{"testing": "value"}`,
+		"yaml_body": "key1: value1\nkey2: value2\nkey3: value3\n",
 		"testURL":   "https://user:password@site.example.com/path/to?query=search#first",
 		"multiURL":  "https://user:password@site.example.com/path/to?query=search&query=results",
 	}
@@ -356,7 +372,8 @@ func TestExpressionEvaluation(t *testing.T) {
 	refParts := strings.Split(testRef, "/")
 	header := http.Header{}
 	header.Add("X-Test-Header", "value")
-	evalEnv := map[string]interface{}{"body": jsonMap, "header": header}
+	req := httptest.NewRequest(http.MethodPost, "https://example.com/testing?param=value", nil)
+	evalEnv := map[string]interface{}{"body": jsonMap, "header": header, "requestURL": req.URL.String()}
 	tests := []struct {
 		name   string
 		expr   string
@@ -446,6 +463,11 @@ func TestExpressionEvaluation(t *testing.T) {
 			expr: "body.json_body.parseJSON().testing == 'value'",
 			want: types.Bool(true),
 		},
+		{
+			name: "parse YAML body in a string",
+			expr: "body.yaml_body.parseYAML().key1 == 'value1'",
+			want: types.Bool(true),
+		},
 		{
 			name: "parse URL",
 			expr: "body.testURL.parseURL().path == '/path/to'",
@@ -461,6 +483,11 @@ func TestExpressionEvaluation(t *testing.T) {
 			expr: "body.multiURL.parseURL().queryStrings['query']",
 			want: types.NewStringList(reg, []string{"search", "results"}),
 		},
+		{
+			name: "parse request url",
+			expr: "requestURL.parseURL().path",
+			want: types.String("/testing"),
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(rt *testing.T) {
@@ -471,11 +498,10 @@ func TestExpressionEvaluation(t *testing.T) {
 					rt.Error(err)
 				}
 			}
-			env, err := makeCelEnv(&http.Request{}, testNS, kubeClient)
+			env, err := makeCelEnv(req, testNS, kubeClient)
 			if err != nil {
 				t.Fatal(err)
 			}
-
 			got, err := evaluate(tt.expr, env, evalEnv)
 			if err != nil {
 				rt.Errorf("evaluate() got an error %s", err)
@@ -486,7 +512,6 @@ func TestExpressionEvaluation(t *testing.T) {
 				rt.Errorf("error evaluating expression: %s", got)
 				return
 			}
-
 			if !got.Equal(tt.want).(types.Bool) {
 				rt.Errorf("evaluate() = %s, want %s", got, tt.want)
 			}
@@ -497,8 +522,10 @@ func TestExpressionEvaluation(t *testing.T) {
 func TestExpressionEvaluation_Error(t *testing.T) {
 	testSHA := "ec26c3e57ca3a959ca5aad62de7213c562f8c821"
 	jsonMap := map[string]interface{}{
-		"value": "testing",
-		"sha":   testSHA,
+		"value":        "testing",
+		"sha":          testSHA,
+		"valid_yaml":   "key1: value1\nkey2: value2\n",
+		"invalid_yaml": "key1: value1key2: value2\n",
 		"pull_request": map[string]interface{}{
 			"commits": []string{},
 		},
@@ -514,12 +541,12 @@ func TestExpressionEvaluation_Error(t *testing.T) {
 		{
 			name: "unknown value",
 			expr: "body.val",
-			want: "no such key: val",
+			want: `expression "body.val" failed to evaluate: no such key: val`,
 		},
 		{
 			name: "invalid syntax",
 			expr: "body.value = 'testing'",
-			want: "Syntax error: token recognition error",
+			want: `failed to parse expression "body.value = 'testing'"`,
 		},
 		{
 			name: "unknown function",
@@ -567,6 +594,21 @@ func TestExpressionEvaluation_Error(t *testing.T) {
 			expr: "body.pull_request.parseJSON().test == 'test'",
 			want: "unexpected type 'map' passed to parseJSON",
 		},
+		{
+			name: "parseYAML decoding non-string",
+			expr: "body.pull_request.parseYAML().key1 == 'value1'",
+			want: "unexpected type 'map' passed to parseYAML",
+		},
+		{
+			name: "unknown key",
+			expr: "body.valid_yaml.parseYAML().key3 == 'value3'",
+			want: "no such key: key3",
+		},
+		{
+			name: "invalid YAML body",
+			expr: "body.invalid_yaml.parseYAML().key1 == 'value1'",
+			want: "failed to decode 'key1: value1key2: value2\n' in parseYAML:",
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(rt *testing.T) {
@@ -617,6 +659,17 @@ func TestURLToMap(t *testing.T) {
 	}
 }
 
+func TestMakeEvalContextWithError(t *testing.T) {
+	req := httptest.NewRequest(http.MethodPost, "/", nil)
+	payload := []byte(`{"tes`)
+
+	_, err := makeEvalContext(payload, req)
+
+	if !matchError(t, "failed to parse the body as JSON: unexpected end of JSON input", err) {
+		t.Fatalf("failed to match the error: %s", err)
+	}
+}
+
 func matchError(t *testing.T, s string, e error) bool {
 	t.Helper()
 	match, err := regexp.MatchString(s, e.Error())
@@ -638,6 +691,15 @@ func makeSecret() *corev1.Secret {
 	}
 }
 
+func mustParseURL(t *testing.T, u string) *url.URL {
+	t.Helper()
+	parsed, err := url.Parse(u)
+	if err != nil {
+		t.Fatal(err)
+	}
+	return parsed
+}
+
 func mustUnmarshal(t *testing.T, b []byte) map[string]interface{} {
 	t.Helper()
 	v := map[string]interface{}{}
