@@ -183,16 +183,6 @@ func Test_applyParamToResourceTemplate(t *testing.T) {
 				rt: json.RawMessage(`{"foo": "$(tt.params.p1)"}`),
 			},
 			want: json.RawMessage(`{"foo": "{\"a\":\"b\"}"}`),
-		}, {
-			name: "deprecated params in resourcetemplate",
-			args: args{
-				param: triggersv1.Param{
-					Name:  "p1",
-					Value: `{"a":"b"}`,
-				},
-				rt: json.RawMessage(`{"p1": "$(params.p1)"}`),
-			},
-			want: json.RawMessage(`{"p1": "{\"a\":\"b\"}"}`),
 		},
 	}
 	for _, tt := range tests {
@@ -207,8 +197,6 @@ func Test_applyParamToResourceTemplate(t *testing.T) {
 
 func Test_ApplyParamsToResourceTemplate(t *testing.T) {
 	rt := json.RawMessage(`{"oneparam": "$(tt.params.oneid)", "twoparam": "$(tt.params.twoid)", "threeparam": "$(tt.params.threeid)"`)
-	rt1 := json.RawMessage(`{"deprecatedParam": "$(params.oneid)"`)
-	rt2 := json.RawMessage(`{"actualParam": "$(tt.params.oneid)", "deprecatedParam": "$(params.twoid)"`)
 	rt3 := json.RawMessage(`{"actualParam": "$(tt.params.oneid)", "invalidParam": "$(tt.params1.invalidid)", "deprecatedParam": "$(params.twoid)"`)
 	type args struct {
 		params []triggersv1.Param
@@ -249,27 +237,6 @@ func Test_ApplyParamsToResourceTemplate(t *testing.T) {
 			},
 			want: json.RawMessage(`{"oneparam": "onevalue", "twoparam": "twovalue", "threeparam": "threevalue"`),
 		},
-		{
-			name: "deprecated params",
-			args: args{
-				params: []triggersv1.Param{
-					{Name: "oneid", Value: "deprecatedParamValue"},
-				},
-				rt: rt1,
-			},
-			want: json.RawMessage(`{"deprecatedParam": "deprecatedParamValue"`),
-		},
-		{
-			name: "both params and tt.params together",
-			args: args{
-				params: []triggersv1.Param{
-					{Name: "oneid", Value: "actualValue"},
-					{Name: "twoid", Value: "deprecatedParamValue"},
-				},
-				rt: rt2,
-			},
-			want: json.RawMessage(`{"actualParam": "actualValue", "deprecatedParam": "deprecatedParamValue"`),
-		},
 		{
 			name: "valid and invalid params together",
 			args: args{
@@ -280,7 +247,7 @@ func Test_ApplyParamsToResourceTemplate(t *testing.T) {
 				},
 				rt: rt3,
 			},
-			want: json.RawMessage(`{"actualParam": "actualValue", "invalidParam": "$(tt.params1.invalidid)", "deprecatedParam": "deprecatedParamValue"`),
+			want: json.RawMessage(`{"actualParam": "actualValue", "invalidParam": "$(tt.params1.invalidid)", "deprecatedParam": "$(params.twoid)"`),
 		},
 	}
 	for _, tt := range tests {
@@ -355,9 +322,16 @@ func Test_ResolveTrigger(t *testing.T) {
 	}{
 		{
 			name: "1 binding",
-			trigger: bldr.Trigger("my-triggertemplate", "v1alpha1",
-				bldr.EventListenerTriggerBinding("my-triggerbinding", "", "my-triggerbinding", "v1alpha1"),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Ref:  "my-triggerbinding",
+					Kind: triggersv1.NamespacedTriggerBindingKind,
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "my-triggertemplate",
+					APIVersion: "v1alpha1",
+				},
+			},
 			want: ResolvedTrigger{
 				TriggerBindings:        []*triggersv1.TriggerBinding{tb},
 				ClusterTriggerBindings: []*triggersv1.ClusterTriggerBinding{},
@@ -366,9 +340,16 @@ func Test_ResolveTrigger(t *testing.T) {
 		},
 		{
 			name: "1 clustertype binding",
-			trigger: bldr.Trigger("my-triggertemplate", "v1alpha1",
-				bldr.EventListenerTriggerBinding("my-clustertriggerbinding", "ClusterTriggerBinding", "my-clustertriggerbinding", "v1alpha1"),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Ref:  "my-clustertriggerbinding",
+					Kind: triggersv1.ClusterTriggerBindingKind,
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "my-triggertemplate",
+					APIVersion: "v1alpha1",
+				},
+			},
 			want: ResolvedTrigger{
 				TriggerBindings:        []*triggersv1.TriggerBinding{},
 				ClusterTriggerBindings: []*triggersv1.ClusterTriggerBinding{ctb},
@@ -377,9 +358,21 @@ func Test_ResolveTrigger(t *testing.T) {
 		},
 		{
 			name: "1 embed binding",
-			trigger: bldr.Trigger("my-triggertemplate", "v1alpha1",
-				bldr.EventListenerTriggerBinding("", "", "my-embed-binding", "v1alpha1", bldr.TriggerBindingParam("key", "value")),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Name: "my-embed-binding",
+					Spec: &triggersv1.TriggerBindingSpec{
+						Params: []triggersv1.Param{{
+							Name:  "key",
+							Value: "value",
+						}},
+					},
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "my-triggertemplate",
+					APIVersion: "v1alpha1",
+				},
+			},
 			want: ResolvedTrigger{
 				TriggerBindings: []*triggersv1.TriggerBinding{
 					{
@@ -399,25 +392,13 @@ func Test_ResolveTrigger(t *testing.T) {
 		{
 			name: "no binding",
 			trigger: triggersv1.EventListenerTrigger{
-				Template: triggersv1.EventListenerTemplate{
+				Template: &triggersv1.EventListenerTemplate{
 					Name:       "my-triggertemplate",
 					APIVersion: "v1alpha1",
 				},
 			},
 			want: ResolvedTrigger{TriggerBindings: []*triggersv1.TriggerBinding{}, ClusterTriggerBindings: []*triggersv1.ClusterTriggerBinding{}, TriggerTemplate: &tt},
 		},
-		{
-			name: "multiple bindings with builder",
-			trigger: bldr.Trigger("my-triggertemplate", "v1alpha1",
-				bldr.EventListenerTriggerBinding("my-triggerbinding", "", "my-triggerbinding", "v1alpha1"),
-				bldr.EventListenerTriggerBinding("my-clustertriggerbinding", "ClusterTriggerBinding", "my-clustertriggerbinding", "v1alpha1"),
-			),
-			want: ResolvedTrigger{
-				TriggerBindings:        []*triggersv1.TriggerBinding{tb},
-				ClusterTriggerBindings: []*triggersv1.ClusterTriggerBinding{ctb},
-				TriggerTemplate:        &tt,
-			},
-		},
 		{
 			name: "multiple bindings",
 			trigger: triggersv1.EventListenerTrigger{
@@ -447,7 +428,7 @@ func Test_ResolveTrigger(t *testing.T) {
 						APIVersion: "v1alpha1",
 					},
 				},
-				Template: triggersv1.EventListenerTemplate{
+				Template: &triggersv1.EventListenerTemplate{
 					Name:       "my-triggertemplate",
 					APIVersion: "v1alpha1",
 				},
@@ -472,7 +453,7 @@ func Test_ResolveTrigger(t *testing.T) {
 					APIVersion: "v1alpha1",
 					Ref:        "my-triggerbinding",
 				}},
-				Template: triggersv1.EventListenerTemplate{
+				Template: &triggersv1.EventListenerTemplate{
 					Name:       "my-triggertemplate",
 					APIVersion: "v1alpha1",
 				},
@@ -507,36 +488,64 @@ func Test_ResolveTrigger_error(t *testing.T) {
 	}{
 		{
 			name: "error triggerbinding",
-			trigger: bldr.Trigger("my-triggertemplate", "v1alpha1",
-				bldr.EventListenerTriggerBinding("invalid-tb-name", "", "invalid-tb-name", "v1alpha1"),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Ref:  "invalid-tb-name",
+					Kind: triggersv1.NamespacedTriggerBindingKind,
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "my-triggertemplate",
+					APIVersion: "v1alpha1",
+				},
+			},
 			getTB:  getTB,
 			getCTB: getCTB,
 			getTT:  getTT,
 		},
 		{
 			name: "error clustertriggerbinding",
-			trigger: bldr.Trigger("my-triggertemplate", "v1alpha1",
-				bldr.EventListenerTriggerBinding("invalid-ctb-name", "ClusterTriggerBinding", "invalid-ctb-name", "v1alpha1"),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Ref:  "invalid-ctb-name",
+					Kind: triggersv1.ClusterTriggerBindingKind,
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "my-triggertemplate",
+					APIVersion: "v1alpha1",
+				},
+			},
 			getTB:  getTB,
 			getCTB: getCTB,
 			getTT:  getTT,
 		},
 		{
 			name: "error triggertemplate",
-			trigger: bldr.Trigger("invalid-tt-name", "v1alpha1",
-				bldr.EventListenerTriggerBinding("my-triggerbinding", "", "my-triggerbinding", "v1alpha1"),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Ref:  "my-triggerbinding",
+					Kind: triggersv1.NamespacedTriggerBindingKind,
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "invalid-tt-name",
+					APIVersion: "v1alpha1",
+				},
+			},
 			getTB:  getTB,
 			getCTB: getCTB,
 			getTT:  getTT,
 		},
 		{
 			name: "error triggerbinding and triggertemplate",
-			trigger: bldr.Trigger("invalid-tt-name", "v1alpha1",
-				bldr.EventListenerTriggerBinding("invalid-tb-name", "", "invalid-tb-name", "v1alpha1"),
-			),
+			trigger: triggersv1.EventListenerTrigger{
+				Bindings: []*triggersv1.EventListenerBinding{{
+					Ref:  "invalid-tb-name",
+					Kind: triggersv1.NamespacedTriggerBindingKind,
+				}},
+				Template: &triggersv1.EventListenerTemplate{
+					Name:       "invalid-tt-name",
+					APIVersion: "v1alpha1",
+				},
+			},
 			getTB:  getTB,
 			getCTB: getCTB,
 			getTT:  getTT,
